# -*- coding: UTF-8 -*-

import ConfigParser

config = ConfigParser.RawConfigParser()

dictTablesWithoutSuffix = ['puppetfacthistory', 'cardchanged', 'clientchanged']

def getSuffixForTable(db, table):
    if 'artixcs' not in db or table.endswith('Temp') or table.lower() in dictTablesWithoutSuffix:
        return ''
    return 'Temp'

def getConfForSection(sectionName, actual_days):
    host = config.get(sectionName, 'host')
    port = config.getint(sectionName, 'port')
    user = config.get(sectionName, 'user')
    passwd = config.get(sectionName, 'passwd')
    db = config.get(sectionName, 'db').replace('dictionaries', 'artixcs')
    tables = [t.strip() + getSuffixForTable(db, t.strip()) for t in config.get(sectionName, 'tables').split(',')]
    return {'host': host, 'port': port, 'user': user, 'passwd': passwd, 'db': db, 'tables': tables, 'actual_days': actual_days}

def readConfig():
    if not config.read('config.ini'):
        return []
    configs = []
    sections = config.sections()
    global_sales_actual_days = 0
    global_dictionaries_actual_days = 0
    if 'MAIN' in sections:
        if config.has_option('MAIN', 'sales_actual_days'):
            global_sales_actual_days = config.getint('MAIN', 'sales_actual_days')
        if config.has_option('MAIN', 'dictionaries_actual_days'):
            global_dictionaries_actual_days = config.getint('MAIN', 'dictionaries_actual_days')
    for sectionName in sections:
        if sectionName.startswith('SALES_DB'):
            actual_days = global_sales_actual_days
        elif sectionName.startswith('DICTIONARIES_DB'):
            actual_days = global_dictionaries_actual_days
        else:
            continue
        if config.has_option(sectionName, 'actual_days'):
            actual_days = config.getint(sectionName, 'actual_days')
        if actual_days > 0:
            configs.append(getConfForSection(sectionName, actual_days))
    return configs